@@ -2,7 +2,8 @@
 #define SORTEDLIBRARY_H
 
 #include <QSortFilterProxyModel>
-#include "library.h"
+
+class Book;
 
 /** Sorted library model. */
 class SortedLibrary: public QSortFilterProxyModel
@@ -13,13 +14,17 @@ public:
     enum SortBy {SortByTitle, SortByAuthor};
     explicit SortedLibrary(QObject *parent = 0);
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
-    void sortBy(SortBy key);
+    void setSortBy(SortBy key);
+    SortBy sortBy();
 
 signals:
 
 public slots:
 
 protected:
+    int compareBy(SortBy key, Book *left, Book *right) const;
+
+private:
     SortBy mSortBy;
 };
 
